@@ -8,6 +8,7 @@
 #' @param background_color Page background color. Leave blank for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors.
 #' @param font_color String. The title font color. Leave blank for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors. \emph{Title color requires using word forms of colors (e.g. "deep-purple"). Also, lighten or darken effects do not work on title colors.}
 #' @param include_fonts Boolean. Should the material font files be included? (This will place the font sources in a directory 'www', at the same location as the app code.)
+#' @param include_nav_bar Boolean. Should the material nav bar be included?
 #' @examples
 #' material_page(
 #'   title = "Example Title",
@@ -16,7 +17,7 @@
 #'   background_color = "blue lighten-4",
 #'   shiny::tags$h1("Page Content")
 #' )
-material_page <- function(..., title = "", nav_bar_fixed = FALSE, nav_bar_color = NULL, background_color = "grey lighten-4", font_color = NULL, include_fonts = FALSE){
+material_page <- function(..., title = "", nav_bar_fixed = FALSE, nav_bar_color = NULL, background_color = "grey lighten-4", font_color = NULL, include_fonts = FALSE, include_nav_bar = TRUE){
   
   materialize_version <- "0.99.0"
   
@@ -84,6 +85,10 @@ material_page <- function(..., title = "", nav_bar_fixed = FALSE, nav_bar_color
     )
   }
   
+  if(!include_nav_bar){
+    material_nav_bar <- shiny::tags$div()
+  }
+  
   shiny::tags$html(
     # Head --------------------------------------------------------------------
     shiny::tags$head(
